@@ -1,11 +1,11 @@
 // have to do this in a hacky way, because removing process right at
 // the start breaks babel, so it fails when coverage is being applied.
-var onSignalExit = require('../../')
+require('../../')
 global.process = null
 delete require.cache[require.resolve('../../')]
-onSignalExit = require('../../')
+const { onExit } = require('../../')
 
-var unwrap = onSignalExit(function (code, signal) {
+var unwrap = onExit(function (code, signal) {
   throw new Error('this should not ever be called')
 })
 
